@@ -16,7 +16,7 @@ __all__ = ('ScriptHost',)
 
 
 logger = logging.getLogger(__name__)
-debug, info, warn = (logger.debug, logger.info, logger.warn,)
+debug, info, warn = (logger.debug, logger.info, logger.warning,)
 
 
 @plugin
@@ -195,7 +195,7 @@ num_types = (int, float)
 
 
 def num_to_str(obj):
-    if isinstance(obj, num_types) and not isinstance(obj, bool):
+    if isinstance(obj, num_types):
         return str(obj)
     else:
         return obj
